@@ -41,6 +41,8 @@
 #endif
 
 #define IDE_VERSION_43 (G_ENCODE_VERSION (43, 0))
+#define IDE_VERSION_44 (G_ENCODE_VERSION (44, 0))
+#define IDE_VERSION_45 (G_ENCODE_VERSION (45, 0))
 
 #if IDE_MAJOR_VERSION == IDE_VERSION_43
 # define IDE_VERSION_PREV_STABLE (IDE_VERSION_43)
@@ -104,3 +106,29 @@
 #else
 # define IDE_AVAILABLE_IN_43 _IDE_EXTERN
 #endif
+
+#if IDE_VERSION_MIN_REQUIRED >= IDE_VERSION_44
+# define IDE_DEPRECATED_IN_44 IDE_DEPRECATED
+# define IDE_DEPRECATED_IN_44_FOR(f) IDE_DEPRECATED_FOR(f)
+#else
+# define IDE_DEPRECATED_IN_44 _IDE_EXTERN
+# define IDE_DEPRECATED_IN_44_FOR(f) _IDE_EXTERN
+#endif
+#if IDE_VERSION_MAX_ALLOWED < IDE_VERSION_44
+# define IDE_AVAILABLE_IN_44 IDE_UNAVAILABLE(44, 0)
+#else
+# define IDE_AVAILABLE_IN_44 _IDE_EXTERN
+#endif
+
+#if IDE_VERSION_MIN_REQUIRED >= IDE_VERSION_45
+# define IDE_DEPRECATED_IN_45 IDE_DEPRECATED
+# define IDE_DEPRECATED_IN_45_FOR(f) IDE_DEPRECATED_FOR(f)
+#else
+# define IDE_DEPRECATED_IN_45 _IDE_EXTERN
+# define IDE_DEPRECATED_IN_45_FOR(f) _IDE_EXTERN
+#endif
+#if IDE_VERSION_MAX_ALLOWED < IDE_VERSION_45
+# define IDE_AVAILABLE_IN_45 IDE_UNAVAILABLE(45, 0)
+#else
+# define IDE_AVAILABLE_IN_45 _IDE_EXTERN
+#endif
