@@ -23,7 +23,10 @@
 #include "config.h"
 
 #include <glib/gi18n.h>
-#include <libpeas/peas.h>
+
+#include <libpeas.h>
+
+#include "ide-marshal.h"
 
 #include "ide-greeter-buttons-section.h"
 #include "ide-greeter-resources.h"
@@ -54,14 +57,10 @@ struct _IdeGreeterWorkspace
   /* Template Widgets */
   IdeHeaderBar             *header_bar;
   GtkBox                   *sections;
-  GtkBox                   *left_box;
-  GtkStack                 *pages;
+  AdwNavigationView        *navigation_view;
   GtkSearchEntry           *search_entry;
-  GtkButton                *back_button;
-  GtkButton                *select_button;
   GtkActionBar             *action_bar;
   GtkActionBar             *projects_action_bar;
-  AdwWindowTitle           *title;
   IdeGreeterButtonsSection *buttons_section;
   AdwStatusPage            *empty_state;
 
@@ -131,7 +130,7 @@ ide_greeter_workspace_has_match (IdeGreeterWorkspace *self)
 static void
 ide_greeter_workspace_filter_sections (PeasExtensionSet *set,
                                        PeasPluginInfo   *plugin_info,
-                                       PeasExtension    *exten,
+                                       GObject    *exten,
                                        gpointer          user_data)
 {
   IdeGreeterWorkspace *self = user_data;
@@ -205,42 +204,29 @@ ide_greeter_workspace_search_entry_changed (IdeGreeterWorkspace *self,
 }
 
 static void
-stack_notify_visible_child_cb (IdeGreeterWorkspace *self,
-                               GParamSpec          *pspec,
-                               GtkStack            *stack)
+navigation_view_notify_visible_page_cb (IdeGreeterWorkspace *self)
 {
   g_autofree gchar *title = NULL;
   g_autofree gchar *full_title = NULL;
-  GtkStackPage *page;
-  GtkWidget *visible_child;
-  gboolean overview;
+  AdwNavigationPage *page;
 
   g_assert (IDE_IS_GREETER_WORKSPACE (self));
-  g_assert (GTK_IS_STACK (stack));
 
-  visible_child = gtk_stack_get_visible_child (stack);
-  page = gtk_stack_get_page (stack, visible_child);
+  page = adw_navigation_view_get_visible_page (self->navigation_view);
 
   if (page != NULL)
     {
-      if ((title = g_strdup (gtk_stack_page_get_title (page))))
+      if ((title = g_strdup (adw_navigation_page_get_title (page))))
         full_title = g_strdup_printf (_("Builder — %s"), title);
     }
 
-  adw_window_title_set_title (self->title, title);
   gtk_window_set_title (GTK_WINDOW (self), full_title);
-
-  overview = ide_str_equal0 ("overview", gtk_stack_get_visible_child_name (stack));
-
-  gtk_widget_set_visible (GTK_WIDGET (self->left_box), overview);
-  gtk_widget_set_visible (GTK_WIDGET (self->back_button), !overview);
-  gtk_widget_set_visible (GTK_WIDGET (self->select_button), overview);
 }
 
 static void
 ide_greeter_workspace_addin_added_cb (PeasExtensionSet *set,
                                       PeasPluginInfo   *plugin_info,
-                                      PeasExtension    *exten,
+                                      GObject    *exten,
                                       gpointer          user_data)
 {
   IdeGreeterSection *section = (IdeGreeterSection *)exten;
@@ -263,7 +249,7 @@ ide_greeter_workspace_addin_added_cb (PeasExtensionSet *set,
 static void
 ide_greeter_workspace_addin_removed_cb (PeasExtensionSet *set,
                                         PeasPluginInfo   *plugin_info,
-                                        PeasExtension    *exten,
+                                        GObject    *exten,
                                         gpointer          user_data)
 {
   IdeGreeterSection *section = (IdeGreeterSection *)exten;
@@ -306,7 +292,7 @@ ide_greeter_workspace_constructed (GObject *object)
                               self);
 
   /* Ensure that no plugin changed our page */
-  ide_greeter_workspace_set_page_name (self, "overview");
+  adw_navigation_view_pop_to_tag (self->navigation_view, "overview");
 
   gtk_widget_grab_focus (GTK_WIDGET (self->search_entry));
 }
@@ -428,6 +414,16 @@ ide_greeter_workspace_open_project (IdeGreeterWorkspace *self,
   if (ret)
     IDE_GOTO (not_ready);
 
+  /* If this project is already open, then just switch to that project instead
+   * of trying to load the project a second time.
+   */
+  if ((workbench = ide_application_find_project_workbench (IDE_APPLICATION_DEFAULT, project_info)))
+    {
+      ide_workbench_activate (workbench);
+      gtk_window_destroy (GTK_WINDOW (self));
+      IDE_EXIT;
+    }
+
   workbench = ide_workspace_get_workbench (IDE_WORKSPACE (self));
 
   ide_greeter_workspace_begin (self);
@@ -459,19 +455,6 @@ not_ready:
   IDE_EXIT;
 }
 
-static void
-ide_greeter_workspace_click_pressed_cb (IdeGreeterWorkspace *self,
-                                        guint                n_press,
-                                        double               x,
-                                        double               y,
-                                        GtkGestureClick     *gesture)
-{
-  g_assert (IDE_IS_GREETER_WORKSPACE (self));
-  g_assert (GTK_IS_GESTURE_CLICK (gesture));
-
-  ide_greeter_workspace_set_page_name (self, "overview");
-}
-
 static void
 ide_greeter_workspace_project_activated_cb (IdeGreeterWorkspace *self,
                                             IdeProjectInfo      *project_info,
@@ -568,8 +551,7 @@ ide_greeter_workspace_page_action (GtkWidget  *widget,
   g_assert (IDE_IS_GREETER_WORKSPACE (self));
   g_assert (g_variant_is_of_type (param, G_VARIANT_TYPE_STRING));
 
-  ide_greeter_workspace_set_page_name (self,
-                                       g_variant_get_string (param, NULL));
+  ide_greeter_workspace_push_page_by_tag (self, g_variant_get_string (param, NULL));
 
   IDE_EXIT;
 }
@@ -661,15 +643,17 @@ ide_greeter_workspace_open_action (GtkWidget  *widget,
   g_autoptr(GFile) projects_dir = NULL;
   GtkFileChooserDialog *dialog;
   GtkFileFilter *all_filter;
-  const GList *list;
+  PeasEngine *engine;
   gint64 last_priority = G_MAXINT64;
+  guint n_items;
 
   IDE_ENTRY;
 
   g_assert (IDE_IS_GREETER_WORKSPACE (self));
   g_assert (param == NULL);
 
-  list = peas_engine_get_plugin_list (peas_engine_get_default ());
+  engine = peas_engine_get_default ();
+  n_items = g_list_model_get_n_items (G_LIST_MODEL (engine));
 
   dialog = g_object_new (GTK_TYPE_FILE_CHOOSER_DIALOG,
                          "action", GTK_FILE_CHOOSER_ACTION_OPEN,
@@ -695,21 +679,21 @@ ide_greeter_workspace_open_action (GtkWidget  *widget,
   gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), all_filter);
 
   /* For testing with no plugins */
-  if (list == NULL)
+  if (n_items == 0)
     gtk_file_filter_add_pattern (all_filter, "*");
 
-  for (; list != NULL; list = list->next)
+  for (guint j = 0; j < n_items; j++)
     {
-      PeasPluginInfo *plugin_info = list->data;
-      const gchar *module_name = peas_plugin_info_get_module_name (plugin_info);
+      g_autoptr(PeasPluginInfo) plugin_info = g_list_model_get_item (G_LIST_MODEL (engine), j);
+      const char *module_name = peas_plugin_info_get_module_name (plugin_info);
       GtkFileFilter *filter;
-      const gchar *pattern;
-      const gchar *content_type;
-      const gchar *name;
-      const gchar *priority;
-      gchar **patterns;
-      gchar **content_types;
-      gint i;
+      const char *pattern;
+      const char *content_type;
+      const char *name;
+      const char *priority;
+      char **patterns;
+      char **content_types;
+      int i;
 
       if (!peas_plugin_info_is_loaded (plugin_info))
         continue;
@@ -894,25 +878,26 @@ ide_greeter_workspace_class_init (IdeGreeterWorkspaceClass *klass)
                                 G_SIGNAL_RUN_LAST,
                                 G_CALLBACK (ide_greeter_workspace_real_open_project),
                                 g_signal_accumulator_true_handled, NULL,
-                                NULL,
-                                G_TYPE_BOOLEAN, 1, IDE_TYPE_PROJECT_INFO);
+                                ide_marshal_BOOLEAN__OBJECT,
+                                G_TYPE_BOOLEAN,
+                                1,
+                                IDE_TYPE_PROJECT_INFO | G_SIGNAL_TYPE_STATIC_SCOPE);
+  g_signal_set_va_marshaller (signals [OPEN_PROJECT],
+                              G_TYPE_FROM_CLASS (klass),
+                              ide_marshal_BOOLEAN__OBJECTv);
 
   ide_workspace_class_set_kind (workspace_class, "greeter");
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/libide-greeter/ide-greeter-workspace.ui");
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, action_bar);
-  gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, back_button);
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, buttons_section);
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, empty_state);
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, header_bar);
-  gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, left_box);
-  gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, pages);
+  gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, navigation_view);
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, projects_action_bar);
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, search_entry);
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, sections);
-  gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, select_button);
-  gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, title);
-  gtk_widget_class_bind_template_callback (widget_class, stack_notify_visible_child_cb);
+  gtk_widget_class_bind_template_callback (widget_class, navigation_view_notify_visible_page_cb);
 
   gtk_widget_class_install_action (widget_class, "greeter.open", NULL, ide_greeter_workspace_open_action);
   gtk_widget_class_install_action (widget_class, "greeter.page", "s", ide_greeter_workspace_page_action);
@@ -937,7 +922,6 @@ ide_greeter_workspace_init (IdeGreeterWorkspace *self)
   };
 
   g_autoptr(GPropertyAction) selection_action = NULL;
-  GtkGesture *gesture;
 
   gtk_widget_init_template (GTK_WIDGET (self));
 
@@ -947,10 +931,6 @@ ide_greeter_workspace_init (IdeGreeterWorkspace *self)
 
   gtk_widget_action_set_enabled (GTK_WIDGET (self), "greeter.reset", FALSE);
 
-  gesture = gtk_gesture_click_new ();
-  gtk_gesture_single_set_button (GTK_GESTURE_SINGLE (gesture), 8);
-  gtk_widget_add_controller (GTK_WIDGET (self), GTK_EVENT_CONTROLLER (gesture));
-
   g_signal_connect_object (self->search_entry,
                            "activate",
                            G_CALLBACK (ide_greeter_workspace_search_entry_activate),
@@ -968,13 +948,7 @@ ide_greeter_workspace_init (IdeGreeterWorkspace *self)
                     G_CALLBACK (gtk_editable_set_text),
                     (gpointer) "");
 
-  g_signal_connect_object (gesture,
-                           "pressed",
-                           G_CALLBACK (ide_greeter_workspace_click_pressed_cb),
-                           self,
-                           G_CONNECT_SWAPPED);
-
-  stack_notify_visible_child_cb (self, NULL, self->pages);
+  navigation_view_notify_visible_page_cb (self);
 }
 
 IdeGreeterWorkspace *
@@ -1144,93 +1118,73 @@ ide_greeter_workspace_set_selection_mode (IdeGreeterWorkspace *self,
 }
 
 /**
- * ide_greeter_workspace_get_page:
+ * ide_greeter_workspace_get_visible_page:
  *
  * Returns: (transfer none) (nullable): the current page, or %NULL if not
  *   page has been added yet.
  */
-GtkWidget *
-ide_greeter_workspace_get_page (IdeGreeterWorkspace *self)
+AdwNavigationPage *
+ide_greeter_workspace_get_visible_page (IdeGreeterWorkspace *self)
 {
   g_return_val_if_fail (IDE_IS_GREETER_WORKSPACE (self), NULL);
 
-  return gtk_stack_get_visible_child (self->pages);
+  return adw_navigation_view_get_visible_page (self->navigation_view);
 }
 
 void
-ide_greeter_workspace_set_page (IdeGreeterWorkspace *self,
-                                GtkWidget           *page)
+ide_greeter_workspace_push_page (IdeGreeterWorkspace *self,
+                                 AdwNavigationPage   *page)
 {
   g_return_if_fail (IDE_IS_GREETER_WORKSPACE (self));
-  g_return_if_fail (!page || GTK_IS_WIDGET (page));
+  g_return_if_fail (ADW_IS_NAVIGATION_PAGE (page));
 
-  if (page != NULL)
-    gtk_stack_set_visible_child (self->pages, page);
-  else
-    gtk_stack_set_visible_child_name (self->pages, "overview");
-}
-
-const char *
-ide_greeter_workspace_get_page_name (IdeGreeterWorkspace *self)
-{
-  g_return_val_if_fail (IDE_IS_GREETER_WORKSPACE (self), NULL);
-
-  return gtk_stack_get_visible_child_name (self->pages);
+  adw_navigation_view_push (self->navigation_view, page);
 }
 
 void
-ide_greeter_workspace_set_page_name (IdeGreeterWorkspace *self,
-                                     const char          *name)
+ide_greeter_workspace_push_page_by_tag (IdeGreeterWorkspace *self,
+                                        const char          *tag)
 {
   g_return_if_fail (IDE_IS_GREETER_WORKSPACE (self));
+  g_return_if_fail (tag != NULL);
 
-  if (name == NULL)
-    name = "overview";
-
-  gtk_stack_set_visible_child_name (self->pages, name);
-  gtk_widget_set_visible (GTK_WIDGET (self->back_button),
-                          !ide_str_equal0 (name, "overview"));
+  adw_navigation_view_push_by_tag (self->navigation_view, tag);
 }
 
 void
 ide_greeter_workspace_add_page (IdeGreeterWorkspace *self,
-                                GtkWidget           *page,
-                                const char          *name,
-                                const char          *title)
+                                AdwNavigationPage   *page)
 {
-  GtkStackPage *child;
-
   g_return_if_fail (IDE_IS_GREETER_WORKSPACE (self));
-  g_return_if_fail (GTK_IS_WIDGET (page));
+  g_return_if_fail (ADW_IS_NAVIGATION_PAGE (page));
 
-  child = gtk_stack_add_named (self->pages, page, name);
-  gtk_stack_page_set_title (child, title);
+  adw_navigation_view_add (self->navigation_view, page);
 }
 
 void
 ide_greeter_workspace_remove_page (IdeGreeterWorkspace *self,
-                                   GtkWidget           *page)
+                                   AdwNavigationPage   *page)
 {
   g_return_if_fail (IDE_IS_GREETER_WORKSPACE (self));
-  g_return_if_fail (GTK_IS_WIDGET (page));
+  g_return_if_fail (ADW_IS_NAVIGATION_PAGE (page));
 
-  gtk_stack_remove (self->pages, page);
+  adw_navigation_view_remove (self->navigation_view, page);
 }
 
 /**
- * ide_greeter_workspace_get_page_named:
+ * ide_greeter_workspace_find_page:
  * @self: a #IdeGreeterWorkspace
  *
- * Gets a page that was added, by it's name.
+ * Finds a page that was added, by its tag.
  *
- * Returns: (transfer none) (nullable): a #GtkWidget or %NULL
+ * Returns: (transfer none) (nullable): a #AdwNavigationPage or %NULL
  */
-GtkWidget *
-ide_greeter_workspace_get_page_named (IdeGreeterWorkspace *self,
-                                      const char          *page_name)
+AdwNavigationPage *
+ide_greeter_workspace_find_page (IdeGreeterWorkspace *self,
+                                 const char          *tag)
 {
   g_return_val_if_fail (IDE_IS_GREETER_WORKSPACE (self), NULL);
-  g_return_val_if_fail (page_name != NULL, NULL);
+  g_return_val_if_fail (tag != NULL, NULL);
 
-  return gtk_stack_get_child_by_name (self->pages, page_name);
+  return adw_navigation_view_find_page (self->navigation_view, tag);
 }
