@@ -39,6 +39,8 @@ struct _IdeTreeExpander
   GIcon           *icon;
   GIcon           *expanded_icon;
 
+  GtkPopover      *popover;
+
   gulong           list_row_notify_expanded;
 };
 
@@ -54,6 +56,7 @@ enum {
   PROP_MENU_MODEL,
   PROP_SUFFIX,
   PROP_TITLE,
+  PROP_USE_MARKUP,
   N_PROPS
 };
 
@@ -145,15 +148,10 @@ ide_tree_expander_click_pressed_cb (IdeTreeExpander *self,
   g_assert (IDE_IS_TREE_EXPANDER (self));
   g_assert (GTK_IS_GESTURE_CLICK (click));
 
-  if (n_press != 1 ||
-      self->list_row == NULL ||
-      !gtk_tree_list_row_is_expandable (self->list_row))
+  if (n_press != 1 || self->list_row == NULL)
     return;
 
-  gtk_widget_activate_action (GTK_WIDGET (self), "listitem.toggle-expand", NULL);
-
   gtk_widget_set_state_flags (GTK_WIDGET (self), GTK_STATE_FLAG_ACTIVE, FALSE);
-  gtk_gesture_set_state (GTK_GESTURE (click), GTK_EVENT_SEQUENCE_CLAIMED);
 }
 
 static void
@@ -166,12 +164,16 @@ ide_tree_expander_click_released_cb (IdeTreeExpander *self,
   g_assert (IDE_IS_TREE_EXPANDER (self));
   g_assert (GTK_IS_GESTURE_CLICK (click));
 
+  gtk_widget_unset_state_flags (GTK_WIDGET (self), GTK_STATE_FLAG_ACTIVE);
+
   if (n_press != 1 ||
       self->list_row == NULL ||
       !gtk_tree_list_row_is_expandable (self->list_row))
     return;
 
-  gtk_widget_unset_state_flags (GTK_WIDGET (self), GTK_STATE_FLAG_ACTIVE);
+
+  gtk_widget_activate_action (GTK_WIDGET (self), "listitem.select", "(bb)", FALSE, FALSE);
+  gtk_widget_activate_action (GTK_WIDGET (self), "listitem.toggle-expand", NULL);
   gtk_gesture_set_state (GTK_GESTURE (click), GTK_EVENT_SEQUENCE_CLAIMED);
 }
 
@@ -207,6 +209,7 @@ static void
 ide_tree_expander_dispose (GObject *object)
 {
   IdeTreeExpander *self = (IdeTreeExpander *)object;
+  GtkWidget *child;
 
   ide_tree_expander_set_list_row (self, NULL);
 
@@ -217,6 +220,19 @@ ide_tree_expander_dispose (GObject *object)
   g_clear_object (&self->list_row);
   g_clear_object (&self->menu_model);
 
+  g_clear_object (&self->icon);
+  g_clear_object (&self->expanded_icon);
+
+  child = gtk_widget_get_first_child (GTK_WIDGET (self));
+
+  while (child != NULL)
+    {
+      GtkWidget *cur = child;
+      child = gtk_widget_get_next_sibling (child);
+      if (GTK_IS_POPOVER (cur))
+        gtk_widget_unparent (cur);
+    }
+
   G_OBJECT_CLASS (ide_tree_expander_parent_class)->dispose (object);
 }
 
@@ -262,6 +278,10 @@ ide_tree_expander_get_property (GObject    *object,
       g_value_set_string (value, ide_tree_expander_get_title (self));
       break;
 
+    case PROP_USE_MARKUP:
+      g_value_set_boolean (value, ide_tree_expander_get_use_markup (self));
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     }
@@ -309,6 +329,10 @@ ide_tree_expander_set_property (GObject      *object,
       ide_tree_expander_set_title (self, g_value_get_string (value));
       break;
 
+    case PROP_USE_MARKUP:
+      ide_tree_expander_set_use_markup (self, g_value_get_boolean (value));
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     }
@@ -378,6 +402,11 @@ ide_tree_expander_class_init (IdeTreeExpanderClass *klass)
                          NULL,
                          (G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS));
 
+  properties [PROP_USE_MARKUP] =
+    g_param_spec_boolean ("use-markup", NULL, NULL,
+                          FALSE,
+                          (G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS));
+
   g_object_class_install_properties (object_class, N_PROPS, properties);
 
   gtk_widget_class_set_layout_manager_type (widget_class, GTK_TYPE_BOX_LAYOUT);
@@ -397,6 +426,7 @@ ide_tree_expander_init (IdeTreeExpander *self)
 
   self->title = g_object_new (GTK_TYPE_LABEL,
                               "halign", GTK_ALIGN_START,
+                              "hexpand", TRUE,
                               "ellipsize", PANGO_ELLIPSIZE_END,
                               "margin-start", 3,
                               "margin-end", 3,
@@ -695,3 +725,95 @@ ide_tree_expander_set_list_row (IdeTreeExpander *self,
 
   g_object_thaw_notify (G_OBJECT (self));
 }
+
+gboolean
+ide_tree_expander_get_use_markup (IdeTreeExpander *self)
+{
+  g_return_val_if_fail (IDE_IS_TREE_EXPANDER (self), FALSE);
+
+  return gtk_label_get_use_markup (GTK_LABEL (self->title));
+}
+
+void
+ide_tree_expander_set_use_markup (IdeTreeExpander *self,
+                                  gboolean         use_markup)
+{
+  g_return_if_fail (IDE_IS_TREE_EXPANDER (self));
+
+  use_markup = !!use_markup;
+
+  if (use_markup != ide_tree_expander_get_use_markup (self))
+    {
+      gtk_label_set_use_markup (GTK_LABEL (self->title), use_markup);
+      g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_USE_MARKUP]);
+    }
+}
+
+static gboolean
+ide_tree_expander_remove_popover_idle (gpointer user_data)
+{
+  gpointer *pair = user_data;
+
+  IDE_ENTRY;
+
+  g_assert (IDE_IS_MAIN_THREAD ());
+  g_assert (pair != NULL);
+  g_assert (IDE_IS_TREE_EXPANDER (pair[0]));
+  g_assert (GTK_IS_POPOVER (pair[1]));
+
+  if (gtk_widget_get_parent (pair[1]) == pair[0])
+    gtk_widget_unparent (pair[1]);
+
+  g_object_unref (pair[0]);
+  g_object_unref (pair[1]);
+  g_free (pair);
+
+  IDE_RETURN (G_SOURCE_REMOVE);
+}
+
+static void
+ide_tree_expander_popover_closed_cb (IdeTreeExpander *self,
+                                     GtkPopover      *popover)
+{
+  g_assert (IDE_IS_MAIN_THREAD ());
+  g_assert (IDE_IS_TREE_EXPANDER (self));
+  g_assert (GTK_IS_POPOVER (popover));
+
+  if (self->popover == popover)
+    {
+      gpointer *pair = g_new (gpointer, 2);
+      pair[0] = g_object_ref (self);
+      pair[1] = g_object_ref (popover);
+      /* We don't want to unparent the widget immediately because it gets
+       * closed _BEFORE_ executing GAction. So removing it will cause the
+       * actions to be unavailable.
+       *
+       * Instead, defer to an idle where we remove the popover.
+       */
+      g_idle_add (ide_tree_expander_remove_popover_idle, pair);
+      self->popover = NULL;
+    }
+}
+
+void
+ide_tree_expander_show_popover (IdeTreeExpander *self,
+                                GtkPopover      *popover)
+{
+  g_return_if_fail (IDE_IS_TREE_EXPANDER (self));
+  g_return_if_fail (GTK_IS_POPOVER (popover));
+
+  gtk_widget_set_parent (GTK_WIDGET (popover), GTK_WIDGET (self));
+
+  g_signal_connect_object (popover,
+                           "closed",
+                           G_CALLBACK (ide_tree_expander_popover_closed_cb),
+                           self,
+                           G_CONNECT_SWAPPED);
+
+  if (self->popover != NULL)
+    gtk_popover_popdown (self->popover);
+
+  self->popover = popover;
+
+  gtk_popover_popup (popover);
+}
