@@ -36,13 +36,10 @@ typedef struct
   GtkBox *left_of_center;
   GtkBox *right;
   GtkBox *right_of_center;
-
-  guint flat : 1;
 } IdeHeaderBarPrivate;
 
 enum {
   PROP_0,
-  PROP_FLAT,
   PROP_MENU_ID,
   N_PROPS
 };
@@ -78,10 +75,6 @@ ide_header_bar_get_property (GObject    *object,
 
   switch (prop_id)
     {
-    case PROP_FLAT:
-      g_value_set_boolean (value, ide_header_bar_get_flat (self));
-      break;
-
     case PROP_MENU_ID:
       g_value_set_string (value, ide_header_bar_get_menu_id (self));
       break;
@@ -101,10 +94,6 @@ ide_header_bar_set_property (GObject      *object,
 
   switch (prop_id)
     {
-    case PROP_FLAT:
-      ide_header_bar_set_flat (self, g_value_get_boolean (value));
-      break;
-
     case PROP_MENU_ID:
       ide_header_bar_set_menu_id (self, g_value_get_string (value));
       break;
@@ -124,11 +113,6 @@ ide_header_bar_class_init (IdeHeaderBarClass *klass)
   object_class->get_property = ide_header_bar_get_property;
   object_class->set_property = ide_header_bar_set_property;
 
-  properties [PROP_FLAT] =
-    g_param_spec_boolean ("flat", NULL, NULL,
-                          FALSE,
-                          (G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS));
-
   properties [PROP_MENU_ID] =
     g_param_spec_string ("menu-id",
                          "Menu ID",
@@ -414,36 +398,3 @@ ide_header_bar_remove (IdeHeaderBar *self,
   g_warning ("Failed to locate widget of type %s within headerbar",
              G_OBJECT_TYPE_NAME (widget));
 }
-
-gboolean
-ide_header_bar_get_flat (IdeHeaderBar *self)
-{
-  IdeHeaderBarPrivate *priv = ide_header_bar_get_instance_private (self);
-
-  g_return_val_if_fail (IDE_IS_HEADER_BAR (self), FALSE);
-
-  return priv->flat;
-}
-
-void
-ide_header_bar_set_flat (IdeHeaderBar *self,
-                         gboolean      flat)
-{
-  IdeHeaderBarPrivate *priv = ide_header_bar_get_instance_private (self);
-
-  g_return_if_fail (IDE_IS_HEADER_BAR (self));
-
-  flat = !!flat;
-
-  if (priv->flat != flat)
-    {
-      priv->flat = flat;
-
-      if (flat)
-        gtk_widget_add_css_class (GTK_WIDGET (priv->header_bar), "flat");
-      else
-        gtk_widget_remove_css_class (GTK_WIDGET (priv->header_bar), "flat");
-
-      g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_FLAT]);
-    }
-}
