@@ -24,7 +24,7 @@
 
 #include <glib/gi18n.h>
 
-#include <libpeas/peas.h>
+#include <libpeas.h>
 
 #include <libide-debugger.h>
 #include <libide-gtk.h>
@@ -170,6 +170,7 @@ static void
 open_free (Open *o)
 {
   g_clear_pointer (&o->addins, g_ptr_array_unref);
+  g_clear_object (&o->position);
   g_clear_object (&o->preferred);
   g_clear_object (&o->file);
   g_clear_pointer (&o->hint, g_free);
@@ -260,7 +261,7 @@ ide_workbench_addin_removed_workspace_cb (IdeWorkspace      *workspace,
 static void
 ide_workbench_addin_added_cb (PeasExtensionSet *set,
                               PeasPluginInfo   *plugin_info,
-                              PeasExtension    *exten,
+                              GObject    *exten,
                               gpointer          user_data)
 {
   IdeWorkbench *self = user_data;
@@ -306,7 +307,7 @@ ide_workbench_addin_added_cb (PeasExtensionSet *set,
 static void
 ide_workbench_addin_removed_cb (PeasExtensionSet *set,
                                 PeasPluginInfo   *plugin_info,
-                                PeasExtension    *exten,
+                                GObject    *exten,
                                 gpointer          user_data)
 {
   IdeWorkbench *self = user_data;
@@ -422,7 +423,7 @@ ide_workbench_constructed (GObject *object)
 }
 
 static void
-ide_workbench_finalize (GObject *object)
+ide_workbench_dispose (GObject *object)
 {
   IdeWorkbench *self = (IdeWorkbench *)object;
 
@@ -433,13 +434,14 @@ ide_workbench_finalize (GObject *object)
 
   g_clear_object (&self->build_system);
   g_clear_object (&self->vcs);
+  g_clear_object (&self->vcs_monitor);
   g_clear_object (&self->search_engine);
   g_clear_object (&self->project_info);
   g_clear_object (&self->cancellable);
-  g_clear_object (&self->context);
   g_clear_object (&self->session);
+  g_clear_object (&self->context);
 
-  G_OBJECT_CLASS (ide_workbench_parent_class)->finalize (object);
+  G_OBJECT_CLASS (ide_workbench_parent_class)->dispose (object);
 }
 
 static void
@@ -494,7 +496,7 @@ ide_workbench_class_init (IdeWorkbenchClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   object_class->constructed = ide_workbench_constructed;
-  object_class->finalize = ide_workbench_finalize;
+  object_class->dispose = ide_workbench_dispose;
   object_class->get_property = ide_workbench_get_property;
   object_class->set_property = ide_workbench_set_property;
 
@@ -554,7 +556,7 @@ ide_workbench_init (IdeWorkbench *self)
 static void
 collect_addins_cb (PeasExtensionSet *set,
                    PeasPluginInfo   *plugin_info,
-                   PeasExtension    *exten,
+                   GObject    *exten,
                    gpointer          user_data)
 {
   GPtrArray *ar = user_data;
@@ -580,7 +582,7 @@ ide_workbench_find_addin (IdeWorkbench *self,
 {
   PeasEngine *engine;
   PeasPluginInfo *plugin_info;
-  PeasExtension *exten = NULL;
+  GObject *exten = NULL;
 
   g_return_val_if_fail (IDE_IS_WORKBENCH (self), NULL);
   g_return_val_if_fail (hint != NULL, NULL);
@@ -944,7 +946,7 @@ ide_workbench_focus_workspace (IdeWorkbench *self,
 static void
 ide_workbench_project_loaded_foreach_cb (PeasExtensionSet *set,
                                          PeasPluginInfo   *plugin_info,
-                                         PeasExtension    *exten,
+                                         GObject    *exten,
                                          gpointer          user_data)
 {
   IdeWorkbenchAddin *addin = (IdeWorkbenchAddin *)exten;
@@ -1057,7 +1059,6 @@ ide_workbench_load_project_completed (IdeWorkbench *self,
    * the build manager to start.
    */
   build_manager = ide_build_manager_from_context (self->context);
-  _ide_build_manager_start (build_manager);
 
   /* Enable actions that are available to projects */
   ide_action_mixin_set_enabled (self, "configure", TRUE);
@@ -1072,6 +1073,10 @@ ide_workbench_load_project_completed (IdeWorkbench *self,
       g_clear_object (&self->session);
     }
 
+  ide_object_message (self->context, _("Project loaded"));
+
+  _ide_build_manager_start (build_manager);
+
   ide_task_return_boolean (task, TRUE);
 }
 
@@ -1193,7 +1198,8 @@ ide_workbench_load_project_async (IdeWorkbench        *self,
   g_autoptr(IdeTask) task = NULL;
   g_autoptr(GFile) parent = NULL;
   g_autofree gchar *name = NULL;
-  const gchar *project_id;
+  const char *project_id;
+  const char *project_name;
   LoadProject *lp;
   GFile *directory;
   GFile *file;
@@ -1232,6 +1238,14 @@ ide_workbench_load_project_async (IdeWorkbench        *self,
       ide_context_set_project_id (self->context, generated);
     }
 
+  if (!(project_name = ide_project_info_get_name (project_info)))
+    project_name = project_id;
+
+  ide_object_message (self->context,
+                      /* translators: %s is replaced with the project name */
+                      _("Loading project “%s”"),
+                      project_name);
+
   if (!ide_project_info_get_directory (project_info) &&
       !ide_project_info_get_file (project_info))
     {
@@ -2341,7 +2355,7 @@ ide_workbench_activate (IdeWorkbench *self)
 static void
 ide_workbench_propagate_vcs_cb (PeasExtensionSet *set,
                                 PeasPluginInfo   *plugin_info,
-                                PeasExtension    *exten,
+                                GObject    *exten,
                                 gpointer          user_data)
 {
   IdeWorkbenchAddin *addin = (IdeWorkbenchAddin *)exten;
@@ -2624,7 +2638,7 @@ ide_workbench_addin_find_by_module_name (IdeWorkbench *workbench,
                                          const gchar  *module_name)
 {
   PeasPluginInfo *plugin_info;
-  PeasExtension *ret = NULL;
+  GObject *ret = NULL;
   PeasEngine *engine;
 
   g_return_val_if_fail (IDE_IS_MAIN_THREAD (), NULL);
