@@ -27,6 +27,7 @@
 #include "ide-content-type.h"
 
 static gchar bundled_lookup_table[256];
+static GIcon *x_zerosize_icon;
 static GHashTable *bundled_by_content_type;
 static GHashTable *bundled_by_full_filename;
 /* This ensures those files get a proper icon when they end with .md
@@ -45,10 +46,14 @@ static const struct {
   { "AUTHORS", "text-x-authors-symbolic" },
   { "MAINTAINERS", "text-x-authors-symbolic" },
   { "Dockerfile", "text-makefile-symbolic" },
+  { "Containerfile", "text-makefile-symbolic" },
   { "package.json", "text-makefile-symbolic" },
   { "pom.xml", "text-makefile-symbolic" },
   { "build.gradle", "text-makefile-symbolic" },
   { "Cargo.toml", "text-makefile-symbolic" },
+  { "pyproject.toml", "text-makefile-symbolic" },
+  { "requirements.txt", "text-makefile-symbolic" },
+  { "go.mod", "text-makefile-symbolic" },
   { "wscript", "text-makefile-symbolic" },
 };
 
@@ -99,7 +104,7 @@ ide_io_init_ctor (void)
   ADD_ICON (bundled_by_content_type, "text-x-changelog-symbolic", NULL);
   ADD_ICON (bundled_by_content_type, "text-x-chdr-symbolic", NULL);
   ADD_ICON (bundled_by_content_type, "text-x-copying-symbolic", NULL);
-  ADD_ICON (bundled_by_content_type, "text-x-cpp-symbolic", NULL);
+  ADD_ICON (bundled_by_content_type, "text-x-c++src-symbolic", NULL);
   ADD_ICON (bundled_by_content_type, "text-x-csrc-symbolic", NULL);
   ADD_ICON (bundled_by_content_type, "text-x-javascript-symbolic", NULL);
   ADD_ICON (bundled_by_content_type, "text-x-python-symbolic", NULL);
@@ -122,6 +127,8 @@ ide_io_init_ctor (void)
   /* Create faster check than doing full string checks */
   for (guint i = 0; i < G_N_ELEMENTS (bundled_check_by_name_prefix); i++)
     bundled_lookup_table[(guint)bundled_check_by_name_prefix[i].searched_prefix[0]] = 1;
+
+  x_zerosize_icon = g_themed_icon_new ("text-x-generic-symbolic");
 }
 
 /**
@@ -157,6 +164,8 @@ ide_g_content_type_get_symbolic_icon (const gchar *content_type,
    */
   if (strcmp (content_type, "inode/directory") == 0)
     return g_content_type_get_symbolic_icon (content_type);
+  else if (strcmp (content_type, "application/x-zerosize") == 0)
+    return g_object_ref (x_zerosize_icon);
 
   /* Special case some weird content-types in the wild, particularly when Wine is
    * installed and taking over a content-type we would otherwise not expect.
