@@ -18,9 +18,12 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
+#define G_LOG_DOMAIN "ide-lsp-search-result"
+
 #include "config.h"
 
 #include "ide-lsp-search-result.h"
+
 #include <libide-core.h>
 #include <libide-editor.h>
 
@@ -46,12 +49,16 @@ ide_lsp_search_result_new (const gchar *title,
                            IdeLocation *location,
                            const gchar *icon_name)
 {
+  g_autoptr(GIcon) gicon = NULL;
+
+  if (icon_name != NULL)
+    gicon = g_themed_icon_new (icon_name);
+
   return g_object_new (IDE_TYPE_LSP_SEARCH_RESULT,
                        "title", title,
                        "subtitle", subtitle,
                        "location", location,
-                       "icon-name", icon_name,
-                       // place search results before the other search providers
+                       "gicon", gicon,
                        "priority", -1,
                        NULL);
 }
@@ -109,17 +116,14 @@ ide_lsp_search_result_activate (IdeSearchResult *result,
 
   IdeLspSearchResult *self = (IdeLspSearchResult *)result;
   IdeWorkspace *workspace;
-  IdeSurface *editor;
 
   g_assert (IDE_IS_LSP_SEARCH_RESULT (self));
   g_assert (GTK_IS_WIDGET (last_focus));
 
-  if (!last_focus)
+  if (!last_focus || !(workspace = ide_widget_get_workspace (last_focus)))
     return;
 
-  if ((workspace = ide_widget_get_workspace (last_focus)) &&
-      (editor = ide_workspace_get_surface_by_name (workspace, "editor")))
-    ide_editor_surface_focus_location (IDE_EDITOR_SURFACE (editor), self->location);
+  ide_editor_focus_location (workspace, NULL, self->location);
 }
 
 static void
