@@ -1,6 +1,6 @@
 /* ide-search-engine.c
  *
- * Copyright 2015-2019 Christian Hergert <chergert@redhat.com>
+ * Copyright 2015-2023 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 #include "config.h"
 
 #include <libide-plugins.h>
-#include <libpeas/peas.h>
+#include <libpeas.h>
 #include <libide-core.h>
 #include <libide-threading.h>
 
@@ -40,6 +40,7 @@ struct _IdeSearchEngine
   IdeExtensionSetAdapter *extensions;
   GPtrArray              *custom_provider;
   guint                   active_count;
+  GListStore             *list;
 };
 
 typedef struct
@@ -51,11 +52,12 @@ typedef struct
 
 typedef struct
 {
-  IdeTask    *task;
-  char       *query;
-  GArray     *sorted;
-  guint       outstanding;
-  guint       max_results;
+  IdeTask           *task;
+  char              *query;
+  GArray            *sorted;
+  IdeSearchCategory  category;
+  guint              outstanding;
+  guint              max_results;
 } Request;
 
 enum {
@@ -104,31 +106,53 @@ request_destroy (Request *r)
 static void
 on_extension_added_cb (IdeExtensionSetAdapter *set,
                        PeasPluginInfo         *plugin_info,
-                       PeasExtension          *exten,
+                       GObject          *exten,
                        gpointer                user_data)
 {
   IdeSearchProvider *provider = (IdeSearchProvider *)exten;
+  IdeSearchEngine *self = user_data;
 
   g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (plugin_info != NULL);
   g_assert (IDE_IS_SEARCH_PROVIDER (provider));
+  g_assert (IDE_IS_SEARCH_ENGINE (self));
 
   ide_search_provider_load (provider);
+
+  g_list_store_append (self->list, provider);
 }
 
 static void
 on_extension_removed_cb (IdeExtensionSetAdapter *set,
                          PeasPluginInfo         *plugin_info,
-                         PeasExtension          *exten,
+                         GObject          *exten,
                          gpointer                user_data)
 {
   IdeSearchProvider *provider = (IdeSearchProvider *)exten;
+  IdeSearchEngine *self = user_data;
 
   g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (plugin_info != NULL);
   g_assert (IDE_IS_SEARCH_PROVIDER (provider));
+  g_assert (IDE_IS_SEARCH_ENGINE (self));
 
   ide_search_provider_unload (provider);
+
+  if (self->list != NULL)
+    {
+      guint n_items = g_list_model_get_n_items (G_LIST_MODEL (self->list));
+
+      for (guint i = 0; i < n_items; i++)
+        {
+          g_autoptr(IdeSearchProvider) item = g_list_model_get_item (G_LIST_MODEL (self->list), i);
+
+          if (item == provider)
+            {
+              g_list_store_remove (self->list, i);
+              break;
+            }
+        }
+    }
 }
 
 static void
@@ -164,14 +188,15 @@ ide_search_engine_parent_set (IdeObject *object,
 }
 
 static void
-ide_search_engine_dispose (GObject *object)
+ide_search_engine_destroy (IdeObject *object)
 {
   IdeSearchEngine *self = (IdeSearchEngine *)object;
 
   g_clear_object (&self->extensions);
   g_clear_pointer (&self->custom_provider, g_ptr_array_unref);
+  g_clear_object (&self->list);
 
-  G_OBJECT_CLASS (ide_search_engine_parent_class)->dispose (object);
+  IDE_OBJECT_CLASS (ide_search_engine_parent_class)->destroy (object);
 }
 
 static void
@@ -199,9 +224,9 @@ ide_search_engine_class_init (IdeSearchEngineClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   IdeObjectClass *i_object_class = IDE_OBJECT_CLASS (klass);
 
-  object_class->dispose = ide_search_engine_dispose;
   object_class->get_property = ide_search_engine_get_property;
 
+  i_object_class->destroy = ide_search_engine_destroy;
   i_object_class->parent_set = ide_search_engine_parent_set;
 
   properties [PROP_BUSY] =
@@ -218,6 +243,7 @@ static void
 ide_search_engine_init (IdeSearchEngine *self)
 {
   self->custom_provider = g_ptr_array_new_with_free_func (g_object_unref);
+  self->list = g_list_store_new (IDE_TYPE_SEARCH_PROVIDER);
 }
 
 IdeSearchEngine *
@@ -250,7 +276,6 @@ ide_search_engine_search_cb (GObject      *object,
   IdeSearchProvider *provider = (IdeSearchProvider *)object;
   g_autoptr(IdeTask) task = user_data;
   g_autoptr(GError) error = NULL;
-  g_autoptr(GListModel) ret = NULL;
   Request *r;
 
   g_assert (IDE_IS_SEARCH_PROVIDER (provider));
@@ -327,6 +352,10 @@ _provider_search_async (IdeSearchProvider *provider,
   g_assert (r != NULL);
   g_assert (IDE_IS_TASK (r->task));
 
+  if (r->category != IDE_SEARCH_CATEGORY_EVERYTHING &&
+      r->category != ide_search_provider_get_category (provider))
+    return;
+
   r->outstanding++;
 
   sort_info.provider = g_object_ref (provider);
@@ -344,7 +373,7 @@ _provider_search_async (IdeSearchProvider *provider,
 static void
 ide_search_engine_search_foreach (IdeExtensionSetAdapter *set,
                                   PeasPluginInfo   *plugin_info,
-                                  PeasExtension    *exten,
+                                  GObject    *exten,
                                   gpointer          user_data)
 {
   IdeSearchProvider *provider = (IdeSearchProvider *)exten;
@@ -375,6 +404,7 @@ ide_search_engine_search_foreach_custom_provider (gpointer data,
 
 void
 ide_search_engine_search_async (IdeSearchEngine     *self,
+                                IdeSearchCategory    category,
                                 const char          *query,
                                 guint                max_results,
                                 GCancellable        *cancellable,
@@ -395,6 +425,7 @@ ide_search_engine_search_async (IdeSearchEngine     *self,
   ide_task_set_priority (task, G_PRIORITY_LOW);
 
   r = request_new ();
+  r->category = category;
   r->query = g_strdup (query);
   r->max_results = max_results;
   r->task = task;
@@ -465,6 +496,7 @@ ide_search_engine_add_provider (IdeSearchEngine   *self,
   g_return_if_fail (IDE_IS_SEARCH_PROVIDER (provider));
 
   g_ptr_array_add (self->custom_provider, g_object_ref (provider));
+  g_list_store_append (self->list, provider);
 }
 
 /**
@@ -482,5 +514,38 @@ ide_search_engine_remove_provider (IdeSearchEngine   *self,
   g_return_if_fail (IDE_IS_SEARCH_ENGINE (self));
   g_return_if_fail (IDE_IS_SEARCH_PROVIDER (provider));
 
-  g_ptr_array_remove (self->custom_provider, provider);
+  if (self->custom_provider != NULL)
+    g_ptr_array_remove (self->custom_provider, provider);
+
+  if (self->list != NULL)
+    {
+      guint n_items = g_list_model_get_n_items (G_LIST_MODEL (self->list));
+
+      for (guint i = 0; i < n_items; i++)
+        {
+          g_autoptr(IdeSearchProvider) item = g_list_model_get_item (G_LIST_MODEL (self->list), i);
+
+          if (item == provider)
+            {
+              g_list_store_remove (self->list, i);
+              break;
+            }
+        }
+    }
+}
+
+/**
+ * ide_search_engine_list_providers:
+ * @self: a #IdeSearchEngine
+ *
+ * Gets a #GListModel that is updated as providers are added or removed.
+ *
+ * Returns: (transfer full): a #GListModel of #IdeSearchProvider
+ */
+GListModel *
+ide_search_engine_list_providers (IdeSearchEngine *self)
+{
+  g_return_val_if_fail (IDE_IS_SEARCH_ENGINE (self), NULL);
+
+  return g_object_ref (G_LIST_MODEL (self->list));
 }
