@@ -93,7 +93,7 @@ typedef struct
 static void
 ide_tree_node_activated_cb (IdeExtensionSetAdapter *addins,
                             PeasPluginInfo         *plugin_info,
-                            PeasExtension          *extension,
+                            GObject          *extension,
                             gpointer                user_data)
 {
   IdeTreeAddin *addin = (IdeTreeAddin *)extension;
@@ -154,7 +154,7 @@ ide_tree_notify_selected_cb (IdeTree            *self,
 static void
 ide_tree_extension_added_cb (IdeExtensionSetAdapter *addins,
                              PeasPluginInfo         *plugin_info,
-                             PeasExtension          *extension,
+                             GObject          *extension,
                              gpointer                user_data)
 {
   IdeTreeAddin *addin = (IdeTreeAddin *)extension;
@@ -171,7 +171,7 @@ ide_tree_extension_added_cb (IdeExtensionSetAdapter *addins,
 static void
 ide_tree_extension_removed_cb (IdeExtensionSetAdapter *addins,
                                PeasPluginInfo         *plugin_info,
-                               PeasExtension          *extension,
+                               GObject          *extension,
                                gpointer                user_data)
 {
   IdeTreeAddin *addin = (IdeTreeAddin *)extension;
@@ -319,7 +319,7 @@ ide_tree_click_released_cb (GtkGestureClick *click,
 static void
 ide_tree_drag_source_prepare_addin_cb (IdeExtensionSetAdapter *adapter,
                                        PeasPluginInfo         *plugin_info,
-                                       PeasExtension          *exten,
+                                       GObject          *exten,
                                        gpointer                user_data)
 {
   IdeTreeAddin *addin = (IdeTreeAddin *)exten;
@@ -439,7 +439,7 @@ ide_tree_drag_source_drag_end_cb (IdeTree       *self,
 static void
 ide_tree_drop_target_accept_foreach_cb (IdeExtensionSetAdapter *adapter,
                                         PeasPluginInfo         *plugin_info,
-                                        PeasExtension          *exten,
+                                        GObject          *exten,
                                         gpointer                user_data)
 {
   IdeTreeAddin *addin = (IdeTreeAddin *)exten;
@@ -675,7 +675,7 @@ ide_tree_drop_target_drop_addin_cb (GObject      *object,
 static void
 ide_tree_drop_target_drop_foreach_cb (IdeExtensionSetAdapter *set,
                                       PeasPluginInfo         *plugin_info,
-                                      PeasExtension          *exten,
+                                      GObject          *exten,
                                       gpointer                user_data)
 {
   IdeTreeAddin *addin = (IdeTreeAddin *)exten;
@@ -753,6 +753,7 @@ ide_tree_list_item_setup_cb (IdeTree                  *self,
   image = g_object_new (GTK_TYPE_IMAGE, NULL);
   expander = g_object_new (IDE_TYPE_TREE_EXPANDER,
                            "suffix", image,
+                           "has-tooltip", TRUE,
                            NULL);
   gtk_list_item_set_child (item, GTK_WIDGET (expander));
 
@@ -950,19 +951,20 @@ ide_tree_list_item_bind_cb (IdeTree                  *self,
 
   ide_tree_expander_set_list_row (expander, row);
 
-#define BIND_PROPERTY(name) \
+#define BIND_PROPERTY(name, to) \
   G_STMT_START { \
-    GBinding *binding = g_object_bind_property (node, name, expander, name, G_BINDING_SYNC_CREATE); \
-    g_object_set_data_full (G_OBJECT (expander), "BINDING_" name, g_object_ref (binding), g_object_unref); \
+    GBinding *binding = g_object_bind_property (node, name, expander, to, G_BINDING_SYNC_CREATE); \
+    g_object_set_data_full (G_OBJECT (expander), "BINDING_" name to, g_object_ref (binding), g_object_unref); \
   } G_STMT_END
 
-  BIND_PROPERTY ("expanded-icon");
-  BIND_PROPERTY ("icon");
-  BIND_PROPERTY ("title");
-  BIND_PROPERTY ("use-markup");
+  BIND_PROPERTY ("expanded-icon", "expanded-icon");
+  BIND_PROPERTY ("icon", "icon");
+  BIND_PROPERTY ("title", "title");
+  BIND_PROPERTY ("title", "tooltip-text");
+  BIND_PROPERTY ("use-markup", "use-markup");
 
   g_object_set_data_full (G_OBJECT (expander),
-                          "BINDING_flags",
+                          "BINDING_flagsflags",
                           g_object_ref (g_object_bind_property_full (node, "flags",
                                                                      suffix, "gicon",
                                                                      G_BINDING_SYNC_CREATE,
@@ -1010,7 +1012,7 @@ ide_tree_list_item_unbind_cb (IdeTree                  *self,
                                         G_CALLBACK (ide_tree_row_notify_expanded_cb),
                                         self);
 
-#define UNBIND_PROPERTY(name) \
+#define UNBIND_PROPERTY(name, to) \
   G_STMT_START { \
     GBinding *binding = g_object_steal_data (G_OBJECT (expander), "BINDING_" name); \
     if (binding != NULL) \
@@ -1020,11 +1022,12 @@ ide_tree_list_item_unbind_cb (IdeTree                  *self,
       } \
   } G_STMT_END
 
-  UNBIND_PROPERTY ("expanded-icon");
-  UNBIND_PROPERTY ("icon");
-  UNBIND_PROPERTY ("title");
-  UNBIND_PROPERTY ("use-markup");
-  UNBIND_PROPERTY ("flags");
+  UNBIND_PROPERTY ("expanded-icon", "expanded-icon");
+  UNBIND_PROPERTY ("icon", "icon");
+  UNBIND_PROPERTY ("title", "title");
+  UNBIND_PROPERTY ("title", "tooltip-text");
+  UNBIND_PROPERTY ("use-markup", "use-markup");
+  UNBIND_PROPERTY ("flags", "flags");
 
 #undef UNBIND_PROPERTY
 
@@ -1429,7 +1432,6 @@ ide_tree_set_selected_node (IdeTree     *self,
 void
 ide_tree_invalidate_all (IdeTree *self)
 {
-  IdeTreePrivate *priv = ide_tree_get_instance_private (self);
   IdeTreeNode *root;
 
   IDE_ENTRY;
