@@ -22,7 +22,6 @@
 
 #include "config.h"
 
-#include <dazzle.h>
 #include <libide-foundry.h>
 #include <libide-gui.h>
 #include <libide-plugins.h>
@@ -98,38 +97,12 @@ gbp_code_index_workbench_addin_project_loaded (IdeWorkbenchAddin *addin,
   gbp_code_index_workbench_addin_notify_paused (self, NULL, service);
 }
 
-static void
-gbp_code_index_workbench_addin_workspace_added (IdeWorkbenchAddin *addin,
-                                                IdeWorkspace      *workspace)
-{
-  GbpCodeIndexWorkbenchAddin *self = (GbpCodeIndexWorkbenchAddin *)addin;
-
-  g_assert (IDE_IS_MAIN_THREAD ());
-  g_assert (GBP_IS_CODE_INDEX_WORKBENCH_ADDIN (self));
-  g_assert (IDE_IS_WORKSPACE (workspace));
-
-  gtk_widget_insert_action_group (GTK_WIDGET (workspace), "code-index", G_ACTION_GROUP (self));
-}
-
-static void
-gbp_code_index_workbench_addin_workspace_removed (IdeWorkbenchAddin *addin,
-                                                  IdeWorkspace      *workspace)
-{
-  g_assert (IDE_IS_MAIN_THREAD ());
-  g_assert (GBP_IS_CODE_INDEX_WORKBENCH_ADDIN (addin));
-  g_assert (IDE_IS_WORKSPACE (workspace));
-
-  gtk_widget_insert_action_group (GTK_WIDGET (workspace), "code-index", NULL);
-}
-
 static void
 workbench_addin_iface_init (IdeWorkbenchAddinInterface *iface)
 {
   iface->load = gbp_code_index_workbench_addin_load;
   iface->unload = gbp_code_index_workbench_addin_unload;
   iface->project_loaded = gbp_code_index_workbench_addin_project_loaded;
-  iface->workspace_added = gbp_code_index_workbench_addin_workspace_added;
-  iface->workspace_removed = gbp_code_index_workbench_addin_workspace_removed;
 }
 
 static void
@@ -150,14 +123,13 @@ gbp_code_index_workbench_addin_paused (GbpCodeIndexWorkbenchAddin *self,
   gbp_code_index_service_set_paused (service, g_variant_get_boolean (state));
 }
 
-DZL_DEFINE_ACTION_GROUP (GbpCodeIndexWorkbenchAddin, gbp_code_index_workbench_addin, {
+IDE_DEFINE_ACTION_GROUP (GbpCodeIndexWorkbenchAddin, gbp_code_index_workbench_addin, {
   { "paused", NULL, NULL, "false", gbp_code_index_workbench_addin_paused },
 })
 
-G_DEFINE_TYPE_WITH_CODE (GbpCodeIndexWorkbenchAddin, gbp_code_index_workbench_addin, G_TYPE_OBJECT,
-                         G_IMPLEMENT_INTERFACE (G_TYPE_ACTION_GROUP,
-                                                gbp_code_index_workbench_addin_init_action_group)
-                         G_IMPLEMENT_INTERFACE (IDE_TYPE_WORKBENCH_ADDIN, workbench_addin_iface_init))
+G_DEFINE_FINAL_TYPE_WITH_CODE (GbpCodeIndexWorkbenchAddin, gbp_code_index_workbench_addin, G_TYPE_OBJECT,
+                               G_IMPLEMENT_INTERFACE (G_TYPE_ACTION_GROUP, gbp_code_index_workbench_addin_init_action_group)
+                               G_IMPLEMENT_INTERFACE (IDE_TYPE_WORKBENCH_ADDIN, workbench_addin_iface_init))
 
 static void
 gbp_code_index_workbench_addin_class_init (GbpCodeIndexWorkbenchAddinClass *klass)
