@@ -42,6 +42,8 @@ const gchar * const  *gbp_flatpak_manifest_get_build_args            (GbpFlatpak
 const gchar * const  *gbp_flatpak_manifest_get_finish_args           (GbpFlatpakManifest   *self);
 const gchar * const  *gbp_flatpak_manifest_get_sdk_extensions        (GbpFlatpakManifest   *self);
 const gchar          *gbp_flatpak_manifest_get_sdk                   (GbpFlatpakManifest   *self);
+const char           *gbp_flatpak_manifest_get_base                  (GbpFlatpakManifest   *self);
+const char           *gbp_flatpak_manifest_get_base_version          (GbpFlatpakManifest   *self);
 const gchar          *gbp_flatpak_manifest_get_platform              (GbpFlatpakManifest   *self);
 gchar               **gbp_flatpak_manifest_get_runtimes              (GbpFlatpakManifest   *self,
                                                                       const gchar          *for_arch);
