@@ -92,7 +92,15 @@ gbp_flatpak_runtime_contains_program_in_path (IdeRuntime   *runtime,
                                program,
                                NULL);
 
-      if (g_file_test (path, G_FILE_TEST_IS_EXECUTABLE))
+      /* Check that the file exists instead of things like IS_EXECUTABLE.  The
+       * reason we MUST check for either EXISTS or _IS_SYMLINK separately is
+       * that EXISTS will check that the destination file exists too. That may
+       * not be possible until the mount namespaces are correctly setup.
+       *
+       * See https://gitlab.gnome.org/GNOME/gnome-builder/-/issues/2050#note_1841120
+       */
+      if (g_file_test (path, G_FILE_TEST_IS_SYMLINK) ||
+          g_file_test (path, G_FILE_TEST_EXISTS))
         {
           ret = TRUE;
           break;
@@ -138,6 +146,21 @@ can_pass_through_finish_arg (const char *arg)
          g_str_has_prefix (arg, "--add-policy");
 }
 
+static gboolean
+maybe_profiling (const char * const *argv)
+{
+  if (argv == NULL)
+    return FALSE;
+
+  for (guint i = 0; argv[i]; i++)
+    {
+      if (strstr (argv[i], "sysprof-agent"))
+        return TRUE;
+    }
+
+   return FALSE;
+}
+
 static gboolean
 gbp_flatpak_runtime_handle_run_context_cb (IdeRunContext       *run_context,
                                            const char * const  *argv,
@@ -248,12 +271,36 @@ gbp_flatpak_runtime_handle_run_context_cb (IdeRunContext       *run_context,
       ide_run_context_append_argv (run_context, "--socket=wayland");
     }
 
+  /* Give access to portals */
   ide_run_context_append_argv (run_context, "--talk-name=org.freedesktop.portal.*");
-  ide_run_context_append_argv (run_context, "--talk-name=org.a11y.Bus");
 
   /* Layering violation, but always give access to profiler */
-  ide_run_context_append_argv (run_context, "--system-talk-name=org.gnome.Sysprof3");
-  ide_run_context_append_argv (run_context, "--system-talk-name=org.freedesktop.PolicyKit1");
+  if (maybe_profiling (argv))
+    {
+      ide_run_context_append_argv (run_context, "--system-talk-name=org.gnome.Sysprof3");
+      ide_run_context_append_argv (run_context, "--system-talk-name=org.freedesktop.PolicyKit1");
+      ide_run_context_append_argv (run_context, "--filesystem=~/.local/share/flatpak:ro");
+      ide_run_context_append_argv (run_context, "--filesystem=host");
+    }
+
+  /* Make A11y bus available to the application */
+  {
+    const char *a11y_bus_unix_path = NULL;
+    const char *a11y_bus_address_suffix = NULL;
+    const char *a11y_bus = gbp_flatpak_get_a11y_bus (&a11y_bus_unix_path, &a11y_bus_address_suffix);
+
+    ide_run_context_append_argv (run_context, "--talk-name=org.a11y.Bus");
+
+    if (a11y_bus != NULL && a11y_bus_unix_path != NULL)
+      {
+        ide_run_context_append_formatted (run_context,
+                                          "--bind-mount=/run/flatpak/at-spi-bus=%s",
+                                          a11y_bus_unix_path);
+        ide_run_context_append_formatted (run_context,
+                                          "--env=AT_SPI_BUS_ADDRESS=unix:path=/run/flatpak/at-spi-bus%s",
+                                          a11y_bus_address_suffix ? a11y_bus_address_suffix : "");
+      }
+  }
 
   /* And last, before our child command, is the staging directory */
   ide_run_context_append_argv (run_context, staging_dir);
