@@ -18,7 +18,6 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include <dazzle.h>
 #include <glib/gi18n.h>
 #include <glib-object.h>
 
@@ -207,7 +206,7 @@ ide_xml_parser_state_processing (IdeXmlParser          *self,
     {
       erroneous_element_name = ide_xml_symbol_node_get_element_name (state->parent_node);
       /* TODO: we need better node comparaison (ns) here */
-      if (!dzl_str_equal0 (erroneous_element_name, element_name))
+      if (!ide_str_equal0 (erroneous_element_name, element_name))
         {
           if (ide_xml_stack_is_empty (state->stack))
             goto error;
@@ -250,7 +249,7 @@ ide_xml_parser_state_processing (IdeXmlParser          *self,
                 goto error;
 
               popped_node = ide_xml_stack_pop (state->stack, &popped_element_name, &parent_node, &depth);
-              if (dzl_str_equal0 (popped_element_name, element_name))
+              if (ide_str_equal0 (popped_element_name, element_name))
                 {
                   ide_xml_symbol_node_set_end_tag_location (popped_node,
                                                             start_line, start_line_offset,
@@ -452,7 +451,7 @@ ide_xml_parser_internal_subset_sax_cb (ParserState   *state,
   g_assert (state != NULL);
   g_assert (IDE_IS_XML_PARSER (state->self));
 
-  if (dzl_str_empty0 ((gchar *)external_id) || dzl_str_empty0 ((gchar *)system_id))
+  if (ide_str_empty0 ((gchar *)external_id) || ide_str_empty0 ((gchar *)system_id))
     return;
 
   entry = ide_xml_schema_cache_entry_new ();
@@ -510,9 +509,9 @@ ide_xml_parser_processing_instruction_sax_cb (ParserState   *state,
       if (NULL != (extension = strrchr (schema_url, '.')))
         {
           ++extension;
-          if (dzl_str_equal0 (extension, "rng"))
+          if (ide_str_equal0 (extension, "rng"))
             kind = SCHEMA_KIND_RNG;
-          else if (dzl_str_equal0 (extension, "xsd"))
+          else if (ide_str_equal0 (extension, "xsd"))
             kind = SCHEMA_KIND_XML_SCHEMA;
           else
             goto fail;
@@ -708,7 +707,7 @@ ide_xml_parser_get_color_tag (IdeXmlParser *self,
 
   g_assert (IDE_IS_XML_PARSER (self));
   g_assert (self->color_tags != NULL);
-  g_assert (!dzl_str_empty0 (str));
+  g_assert (!ide_str_empty0 (str));
 
   tag = &g_array_index (self->color_tags, ColorTag, id);
   return g_strdup_printf ("%s<span foreground=\"%s\" background=\"%s\">%s%s%s</span>%s",
@@ -748,7 +747,7 @@ init_color_tags (IdeXmlParser *self)
       tag_set = FALSE;
       if (scheme != NULL)
         {
-          tag_name = g_strconcat ("symboltree::", tag_ptr->name, NULL);
+          tag_name = g_strconcat ("-Builder:", tag_ptr->name, NULL);
           if (NULL != (style = gtk_source_style_scheme_get_style (scheme, tag_name)))
             {
               g_object_get (style, "foreground", &foreground, NULL);
@@ -796,7 +795,7 @@ editor_settings_changed_cb (IdeXmlParser *self,
 {
   g_assert (IDE_IS_XML_PARSER (self));
 
-  if (dzl_str_equal0 (key, "style-scheme-name"))
+  if (ide_str_equal0 (key, "style-scheme-name"))
     init_color_tags (self);
 }
 
